@@ -21,7 +21,7 @@ namespace
 class CheckboxDelegate : public QItemDelegate
 {
 public:
-    CheckboxDelegate(QObject *parent)
+    explicit CheckboxDelegate(QObject *parent)
         : QItemDelegate(parent)
     {
     }
@@ -33,7 +33,7 @@ public:
         // Drawing the checkbox
         auto checkRect = wholeRect;
         checkRect.setWidth(checkRect.height());
-        drawCheck(painter, option, checkRect, option.state & QStyle::State_Selected ? Qt::Checked : Qt::Unchecked);
+        drawCheck(painter, option, checkRect, (option.state & QStyle::State_Selected) ? Qt::Checked : Qt::Unchecked);
 
         // Drawing the text
         auto textRect = wholeRect;
@@ -106,8 +106,8 @@ void ConfigureActivitiesWidget::setActivitiesSettings(const ActivitiesBaseManage
     bool listIsEmpty{activitySettings.activities.isEmpty()};
     mListView->setEnabled(activitySettings.enabled);
     mEnableActivitiesSupport->setChecked(activitySettings.enabled);
-    bool hasFoundActivities = false;
     if (!listIsEmpty) {
+        bool hasFoundActivities = false;
         for (int row = 0; row < model->rowCount(); ++row) {
             const auto index = model->index(row, 0);
             const auto activity = model->data(index, KActivities::ActivitiesModel::ActivityId).toString();
