@@ -9,7 +9,6 @@
 #include "pimcommon_export.h"
 
 #include <KPluginMetaData>
-#include <QPair>
 #include <QString>
 #include <QStringList>
 
@@ -34,9 +33,14 @@ public:
 
 namespace PluginUtil
 {
+struct PIMCOMMON_EXPORT PluginsStateList {
+    QStringList enabledPluginList;
+    QStringList disabledPluginList;
+};
+
 [[nodiscard]] PIMCOMMON_EXPORT bool
 isPluginActivated(const QStringList &enabledPluginsList, const QStringList &disabledPluginsList, bool isEnabledByDefault, const QString &pluginId);
-[[nodiscard]] PIMCOMMON_EXPORT QPair<QStringList, QStringList> loadPluginSetting(const QString &groupName, const QString &prefixSettingKey);
+[[nodiscard]] PIMCOMMON_EXPORT PluginsStateList loadPluginSetting(const QString &groupName, const QString &prefixSettingKey);
 PIMCOMMON_EXPORT void
 savePluginSettings(const QString &groupName, const QString &prefixSettingKey, const QStringList &enabledPluginsList, const QStringList &disabledPluginsList);
 [[nodiscard]] PIMCOMMON_EXPORT PimCommon::PluginUtilData createPluginMetaData(const KPluginMetaData &metaData);
